Installation
============

The `Python Packaging Guide`_ contains general information about how to manage
your project and dependencies.

.. _Python Packaging Guide: https://packaging.python.org/current/

Released version
----------------

Install or upgrade using pip. ::

    pip install -U Flask-WTF

Development
-----------

The latest code is available from `GitHub`_. Clone the repository then install
using pip. ::

    git clone https://github.com/wtforms/flask-wtf
    pip install -e ./flask-wtf

Or install the latest build from an `archive`_. ::

    pip install -U https://github.com/wtforms/flask-wtf/archive/main.tar.gz

.. _GitHub: https://github.com/wtforms/flask-wtf
.. _archive: https://github.com/wtforms/flask-wtf/archive/main.tar.gz
